@@ -16,11 +16,15 @@
 
 from __future__ import print_function
 import unittest
-import json
 from requests import codes as http_status
 from mock import MagicMock
-import requests
 import requests_mock
+
+# Note we are deliberately using simplejson (instead of json) because
+# that's what the requests module uses and we want to raise the same
+# types of exceptions, not exceptions from the generic "json" module.
+import simplejson
+
 import opsramp.binding
 
 
@@ -28,7 +32,7 @@ class FakeResp(object):
     def __init__(self, content, request):
         self.status_code = http_status.OK
         self.content = content
-        self.text = json.dumps(self.content)
+        self.text = simplejson.dumps(self.content)
         self.json_fail = False
         self.request = request
 
@@ -124,7 +128,7 @@ class ApiObjectTest(unittest.TestCase):
 
             faked_response = FakeResp(
                 content=expected,
-                request=requests.get(self.fake_url).request
+                request=self.ao.session.get(self.fake_url).request
             )
             actual = self.ao.process_result(self.fake_url, faked_response)
             assert type(actual) is dict
@@ -137,7 +141,7 @@ class ApiObjectTest(unittest.TestCase):
 
             faked_response = FakeResp(
                 content=['nothing'],
-                request=requests.get(self.fake_url).request
+                request=self.ao.session.get(self.fake_url).request
             )
 
             faked_response.json_fail = True
@@ -156,7 +160,7 @@ class ApiObjectTest(unittest.TestCase):
 
             faked_response = FakeResp(
                 content=['nothing'],
-                request=requests.get(self.fake_url).request
+                request=self.ao.session.get(self.fake_url).request
             )
             faked_response.status_code = http_status.BAD_REQUEST
 
@@ -211,7 +215,7 @@ class ApiObjectTest(unittest.TestCase):
             # Build the initial (faked) response based on the above
             faked_response = FakeResp(
                 content=request_responses[0]['json'],
-                request=requests.get(self.fake_url).request
+                request=self.ao.session.get(self.fake_url).request
             )
             actual = self.ao.process_result(self.fake_url, faked_response)
             assert type(actual) is dict
